@@ -1,51 +1,37 @@
 import argparse
 import logging
+import re
 import os
 import sys
 from tempfile import mkstemp
-from lxml import etree
 from pywizard.context import Context
 from pywizard.resources.sudo import RequireSudoException
 import pywizard.api as pw
 
+# allow monkey-patching on test
+try:
+    _raw_input = raw_input
+except NameError:
+    _raw_input = input
+
 try:
     from urllib.request import urlopen
 except ImportError:
     from urllib import urlopen
 
 
-def configure_logger(args):
-    logging.basicConfig(format='%(asctime)s %(levelname)-8s %(message)s',
-                        datefmt='%a, %d %b %Y %H:%M:%S',
-                        level=logging.getLevelName(args.log_level))
-
-def common_init(args):
-    configure_logger(args)
-
-
 def execute(path, ctx):
-    if os.path.exists(path):
-        sys.path.insert(0, os.path.dirname(path))
-        exec(compile(open(path).read(), path, 'exec'), globals(), locals())
-    else:
-        f = urlopen(path)
-        handle, fileaname = mkstemp()
+    sys.path.insert(0, os.path.dirname(path))
+    exec(compile(open(path).read(), path, 'exec'), globals(), locals())
 
-        with open(fileaname, 'w+') as tmp:
-            tmp.write(f.read())
-
-        f.close()
-
-        exec(compile(open(fileaname).read(), fileaname, 'exec'), globals(), locals())
-
-        os.remove(fileaname)
 
 def yn_choice(message, default='y'):
     choices = 'Y/n' if default.lower() in ('y', 'yes') else 'y/N'
-    choice = raw_input("%s (%s) " % (message, choices))
+    choice = _raw_input("%s (%s) " % (message, choices))
     values = ('y', 'yes', '') if default == 'y' else ('y', 'yes')
     return choice.strip().lower() in values
 
+
 def apply_action(args):
     """
     Handles pywizard execution
@@ -59,35 +45,40 @@ def apply_action(args):
         execute(path, context)
 
     if args.tree:
-        print(etree.tostring(context.to_xml(), pretty_print=True))
+        more_indent = re.compile(r'^(\s*)', re.MULTILINE)
+        print(more_indent.sub(r'\1\1\1', context.to_xml().prettify()))
 
     changes = context.changeset()
 
-    if not args.force:
-        print('\n')
-        for item in changes.items:
-            print('\t - %s' % item)
+    if changes.needed():
+        if not args.force:
+            print('\nChanges to be applied:\n')
+            for item in changes.items:
+                print('\t - %s' % item.description)
 
-    if not args.dry:
-        if args.force or yn_choice('Apply changes?'):
-            changes.commit()
+        if not args.dry:
+            if args.force or yn_choice('\nApply?', default='n'):
+                changes.commit()
+
+                print('\nChanges has been successfully applied.\n')
+
+            else:
+                print('\nNo changes has been made.\n')
+
+    else:
+        print('\nNo changes needed.\n')
 
     logging.info('Pywizard execution completed')
 
 
 def build_argparser():
     parser = argparse.ArgumentParser()
-    parser.add_argument('--log-level', type=str, help='Log level. Useful ones: DEBUG, INFO, ERROR',
-                        default='INFO')
-    parser.add_argument('-v', action='store_const', dest='log-level', const='DEBUG', help='Set log level to debug',
-                        default='INFO')
-
     subparsers = parser.add_subparsers()
 
     subpackage = subparsers.add_parser('apply', help='Execute provision script, collect all resources and apply them.')
     subpackage.add_argument('path', help='Specify path to provision script. provision.py in current'
                                                  'directory by default. Also may include url.', default='provision.py')
-    subpackage.add_argument('--rollback', action='store_true', default=False, help='If specified will rollback all'
+    subpackage.add_argument('-r', '--rollback', action='store_true', default=False, help='If specified will rollback all'
                                                                                    'resources applied.')
     subpackage.add_argument('--tree', action='store_true', default=False, help='Print resource tree')
     subpackage.add_argument('--dry', action='store_true', default=False, help='Just print changes list')
@@ -110,20 +101,24 @@ def pywizard_cmd(args=None):
           /____/
 
     ''')
-        args = sys.argv
+        args = sys.argv[1:]
 
-    args = build_argparser().parse_args(args=args)
+    parser = build_argparser()
 
-    configure_logger(args)
+    if not args:
+        parser.print_usage()
+        print('\n')
 
-    try:
-
-
-        args.func(args)
-
-    except RequireSudoException as e:
-        sys.stderr.write('\nCurrent command requires Superuser priveleges.\nReason: %s\n\n' % e.message)
-        exit(1)
-    except KeyboardInterrupt:
-        print('\nInterrupted by user.')
         exit(1)
+    else:
+        args = parser.parse_args(args=args)
+
+        try:
+            args.func(args)
+
+        except RequireSudoException as e:
+            sys.stderr.write('\nCurrent command requires Superuser priveleges.\nReason: %s\n\n' % e.message)
+            exit(1)
+        except KeyboardInterrupt:
+            print('\nInterrupted by user.')
+            exit(1)
