@@ -3,7 +3,7 @@ Describe smallest pieces of pywizard domain model
 """
 from contextlib import contextmanager
 from logging import debug
-from lxml import etree
+from bs4 import BeautifulSoup
 
 
 class CanNotResolveConflictError(Exception):
@@ -251,11 +251,15 @@ class ResourceSet(Item):
         return changes
 
     def to_xml(self):
-        el = etree.Element('resource_set', name=self.name, rollback=str(self.rollback_mode), executed=str(self._executed))
+        el = BeautifulSoup().new_tag('resource_set', )
+        el['name'] = self.name
+        el['rollaback'] = self.rollback_mode
+        el['executed'] = self._executed
 
         if self._items:
             for item in self._items:
                 el.append(item.to_xml())
+                el.append('\n')
 
         return el
 
