@@ -1,10 +1,5 @@
-import apt
-from pywizard.compat.os_debian.facts import os_ubuntu
 
-from pywizard.resources.shell import shell
-
-from pywizard.core.env import worker
-from pywizard.resources.package import PackageProvider, register_package_provider
+from pywizard.resources.resource_package import PackageProvider
 
 
 class AptPackageProvider(PackageProvider):
@@ -13,10 +8,8 @@ class AptPackageProvider(PackageProvider):
     def get_key():
         return 'apt'
 
-    def can_install_system_packages(self):
-        return os_ubuntu()
-
     def install_packages(self, packages, version=None):
+        import apt
         cache = apt.Cache()
         for package in packages:
             cache[package].mark_install()
@@ -24,6 +17,7 @@ class AptPackageProvider(PackageProvider):
         cache.commit()
 
     def uninstall_packages(self, packages, version=None):
+        import apt
         cache = apt.Cache()
         for package in packages:
             cache[package].mark_delete()
@@ -31,7 +25,7 @@ class AptPackageProvider(PackageProvider):
         cache.commit()
 
     def get_installed(self, packages):
-
+        import apt
         cache = apt.Cache()
         installed = []
         for package in packages:
@@ -40,9 +34,3 @@ class AptPackageProvider(PackageProvider):
 
         return set(installed)
 
-#
-# def install_libs():
-#     shell('apt-get install libapt-pkg-dev')
-#     shell('pip install python-apt')
-# worker.env.requirements.append(install_libs)
-
