@@ -1,12 +1,5 @@
-from pywizard.compat.os_centos.facts import os_centos
-from pywizard.resources.package import PackageProvider, register_package_provider
-from pywizard.process import run
-import yum
-
-
-def yum_command(command):
-    return '%s %s' % ('yum', command)
 
+from pywizard.resources.resource_package import PackageProvider
 
 class YumPackageProvider(PackageProvider):
 
@@ -14,10 +7,8 @@ class YumPackageProvider(PackageProvider):
     def get_key():
         return 'yum'
 
-    def can_install_system_packages(self):
-        return os_centos()
-
     def install_packages(self, packages, version=None):
+        import yum
         yb = yum.YumBase()
         for package in packages:
             yb.install(name=package)
@@ -25,6 +16,7 @@ class YumPackageProvider(PackageProvider):
         yb.processTransaction()
 
     def uninstall_packages(self, packages, version=None):
+        import yum
         yb = yum.YumBase()
         yb.repos.enableRepo('remi')
         for package in packages:
@@ -33,6 +25,7 @@ class YumPackageProvider(PackageProvider):
         yb.processTransaction()
 
     def get_installed(self, packages):
+        import yum
         installed = []
         yb = yum.YumBase()
         yb.conf.cache = True
@@ -43,5 +36,3 @@ class YumPackageProvider(PackageProvider):
                 installed.append(pkg.name)
 
         return set(installed)
-
-register_package_provider(YumPackageProvider)
\ No newline at end of file
